==> lasta-di-0.6.1-RC2-sources.jar: org/lastaflute/di/helper/beans/PropertyDesc.java <==
/*
 * Copyright 2014-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.helper.beans;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import org.lastaflute.di.helper.beans.exception.IllegalPropertyRuntimeException;

/**
 * @author modified by jflute (originated in Seasar)
 */
public interface PropertyDesc {

    String getPropertyName();

    Class<?> getPropertyType();

    Method getReadMethod();

    void setReadMethod(Method readMethod);

    boolean hasReadMethod();

    Method getWriteMethod();

    void setWriteMethod(Method writeMethod);

    boolean hasWriteMethod();

    boolean isReadable();

    boolean isWritable();

    Field getField();

    void setField(Field field);

    Object getValue(Object target) throws IllegalStateException;

    void setValue(Object target, Object value) throws IllegalPropertyRuntimeException, IllegalStateException;

    Object convertIfNeed(Object value);

    BeanDesc getBeanDesc();

    boolean isParameterized();

    ParameterizedClassDesc getParameterizedClassDesc();

    Class<?> getElementClassOfCollection();

    Class<?> getKeyClassOfMap();

    Class<?> getValueClassOfMap();
}

==> lasta-di-0.7.1-RC2-sources.jar: org/lastaflute/di/helper/beans/PropertyDesc.java <==
/*
 * Copyright 2015-2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.helper.beans;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import org.lastaflute.di.helper.beans.exception.BeanIllegalPropertyException;

/**
 * @author modified by jflute (originated in Seasar)
 */
public interface PropertyDesc {

    String getPropertyName();

    Class<?> getPropertyType();

    Method getReadMethod();

    void setReadMethod(Method readMethod);

    boolean hasReadMethod();

    Method getWriteMethod();

    void setWriteMethod(Method writeMethod);

    boolean hasWriteMethod();

    boolean isReadable();

    boolean isWritable();

    Field getField();

    void setField(Field field);

    Object getValue(Object target) throws IllegalStateException;

    void setValue(Object target, Object value) throws BeanIllegalPropertyException, IllegalStateException;

    Object convertIfNeed(Object value);

    BeanDesc getBeanDesc();

    boolean isParameterized();

    ParameterizedClassDesc getParameterizedClassDesc();

    Class<?> getElementClassOfCollection();

    Class<?> getKeyClassOfMap();

    Class<?> getValueClassOfMap();
}
